import os


def make_semester_path(mata_kuliah: str, semester: int):
    current_path = os.getcwd()
    path = os.path.join(current_path, f"semester {semester}")
    os.mkdir(path)
    mata_kuliahs = mata_kuliah.split(",")
    contents = ["1. tugas", "0. materi",
                "2. quiz", "3. UTS", "4. UAS", "lain-lain"]

    current_path = path
    for mata_kuliah in mata_kuliahs:
        path = os.path.join(current_path, mata_kuliah)
        os.mkdir(path)

        current_current_path = path
        for content in contents:
            path_path = os.path.join(current_current_path, content)
            os.mkdir(path_path)



import sys
from .semester import make_semester_path


def mkfol():
    if len(sys.argv) <= 1:
        print("Usage: mkfol -h")
        return

    if sys.argv[1] == "-h" or sys.argv[1] == "--help":
        print(
            """
            misc:
            -h / --help : show this help
            -v / --version : show version

            main feature:
            -s / --semester : make semester folder
            
            usage:
            mkfol -s <semester> <mata kuliah (separate with comma)>
            """
        )
        return

    if sys.argv[1] == "-v" or sys.argv[1] == "--version":
        print("mkfol version 1.0")
        return

    if sys.argv[1] == "-s" or sys.argv[1] == "--semester":
        semester = int(sys.argv[2])
        mata_kuliah = sys.argv[3]
        make_semester_path(mata_kuliah, semester)
        print("semester folder created")
        return

    print("Please enter valid arguments! mkfol -h for help")


if __name__ == "__main__":
    mkfol()



import setuptools
setuptools.setup(
    name='mkfol',
    version='1.0',
    packages=["mkfol"],
    entry_points={
        'console_scripts': ['mkfol=mkfol.mkfol:mkfol']
    },
    author='Sulthan Abiyyu Hakim',
    author_email="sabiyyuhakim@student.ub.ac.id",
    description='Folder maker based on template',
    install_requires=[
        'setuptools',
    ],
    python_requires='>=3.5',
)
